@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2017 Montel Laurent <montel@kde.org>
+  Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,8 +20,7 @@
 
 #include "mailimporter_export.h"
 
-namespace MailImporter
-{
+namespace MailImporter {
 class MAILIMPORTER_EXPORT MessageStatus
 {
 public:
@@ -40,10 +39,10 @@ public:
     void setForwarded(bool state);
     bool isForwarded() const;
 private:
-    bool mRead;
-    bool mDeleted;
-    bool mReplied;
-    bool mForwarded;
+    bool mRead = false;
+    bool mDeleted = false;
+    bool mReplied = false;
+    bool mForwarded = false;
 };
 }
 #endif // MESSAGESTATUS_H
